#!/bin/sh
#
#	aegis - project change supervisor
#	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# MANIFEST: shell script to generate the Mafile file
#
lib_files=
man1_files=
man5_files=
fmtgen_files=
txt2c_files=
aegis_files=
test_files=
common_files=
clean_files="core bin/fmtgen bin/txt2c"
for file in $*
do
	case $file in

	fmtgen/*.y)
		stem=`echo $file | sed 's/\.y$//'`
		clean_files="$clean_files ${stem}.gen.c ${stem}.gen.h"
		fmtgen_files="$fmtgen_files ${stem}.gen.o"
		clean_files="$clean_files ${stem}.gen.o"
		;;

	fmtgen/*.c)
		stem=`echo $file | sed 's/\.c$//'`
		fmtgen_files="$fmtgen_files ${stem}.o"
		clean_files="$clean_files ${stem}.o"
		;;

	txt2c/*.c)
		root=`basename $file .c`
		txt2c_files="$txt2c_files txt2c/${root}.o"
		clean_files="$clean_files txt2c/${root}.o"
		;;

	aegis/*.def)
		root=`basename $file .def`
		clean_files="$clean_files aegis/${root}.c aegis/${root}.h"
		aegis_files="$aegis_files aegis/${root}.o"
		clean_files="$clean_files aegis/${root}.o"
		;;

	aegis/*.y)
		stem=`echo $file | sed 's/\.y$//'`
		clean_files="$clean_files ${stem}.gen.c ${stem}.gen.h"
		aegis_files="$aegis_files ${stem}.gen.o"
		clean_files="$clean_files ${stem}.gen.o"
		;;

	aegis/*.c)
		stem=`echo $file | sed 's/\.c$//'`
		aegis_files="$aegis_files ${stem}.o"
		clean_files="$clean_files ${stem}.o"
		;;

	common/*.c)
		root=`basename $file .c`
		common_files="$common_files common/${root}.o"
		clean_files="$clean_files common/${root}.o"
		;;

	man1/*.1)
		root=`basename $file .1`
		clean_files="$clean_files man1/${root}.h"
		man1_files="$man1_files \$(mandir)/$file"
		;;

	man1/*.so)
		root=`basename $file .so`
		clean_files="$clean_files man1/${root}.h"
		;;

	man5/*.5)
		man5_files="$man5_files \$(mandir)/$file"
		;;

	test/*/*)
		root=`basename $file .sh`
		test_files="$test_files $root"
		;;

	lib/*)
		rest=`echo $file | sed 's/^....//'`
		lib_files="$lib_files \$(libdir)/$rest"
		;;

	*)
		;;
	esac
done

#
# clean up the area
#
echo ''
echo 'clean-obj:'
echo '	rm -f' $clean_files
echo ''
echo 'clean: clean-obj'
echo '	rm -f bin/aegis bin/xaegis'
echo ''
echo 'distclean: clean'
echo '	rm -f config.status Makefile common/config.h'

echo
echo "CommonFiles =" $common_files

echo ""
echo ".bin:"
echo "	mkdir bin"
echo "	@touch .bin"

echo
echo "FmtgenFiles =" $fmtgen_files
echo
echo "bin/fmtgen: $(FmtgenFiles) $(CommonFiles) .bin"
echo "	@sleep 1"
echo "	$(CC) -o bin/fmtgen $(FmtgenFiles) $(CommonFiles) $(LIBS)"
echo "	@sleep 1"

echo
echo "Txt2cFiles =" $txt2c_files
echo
echo "bin/txt2c: $(Txt2cFiles) $(CommonFiles) .bin"
echo "	@sleep 1"
echo "	$(CC) -o bin/txt2c $(Txt2cFiles) $(CommonFiles) $(LIBS)"
echo "	@sleep 1"

echo
echo "AegisFiles =" $aegis_files
echo
echo "bin/aegis: $(AegisFiles) $(CommonFiles) .bin"
echo "	@sleep 1"
echo "	$(CC) -o bin/aegis $(AegisFiles) $(CommonFiles) $(LIBS) -lm"
echo "	@sleep 1"

echo
echo "sure:" $test_files
echo "	@echo Passed All Tests"

#
# This command could all be done with install,
# but it has two incompatible forms:
#	$(INSTALL_PROGRAM) -m 4755 -o root bin/aegis $(bindir)/aegis
#	$(INSTALL_PROGRAM) -m 4755 -u root bin/aegis $(bindir)/aegis
# The form which takes -u interprets -o as something else.
# This is not determined automagically by autoconf.
#
echo ''
echo '$(bindir)/aegis: bin/aegis'
echo '	$(INSTALL_PROGRAM) bin/aegis $@'
echo '	chown root $@'
echo '	chmod 4755 $@'

#
# The mkdir could all be done with install,
# but it has two incompatible forms:
#	$(INSTALL_PROGRAM) -d -m 0755 -o $(AEGIS_UID) -g $(AEGIS_GID) $(libdir)
#	$(INSTALL_PROGRAM) -d -m 0755 -u $(AEGIS_UID) -g $(AEGIS_GID) $(libdir)
# The form which takes -u interprets -o as something else.
# This is not determined automagically by autoconf.
# Also, some INSTALL programs do not understand numeric group/user names
#
echo ""
echo "#"
echo "# Note: if $(libdir) has the wrong owner or the wrong permissions,"
echo "#	aegis will exit with a fatal error."
echo "#"
echo ".libdir:"
echo "	-mkdir $(libdir)"
echo "	chown $(AEGIS_UID) $(libdir)"
echo "	chgrp $(AEGIS_GID) $(libdir)"
echo "	chmod 0755 $(libdir)"
echo "	@touch .libdir"
echo "	@sleep 1"

echo ''
echo '.libdir.report: .libdir'
echo '	-mkdir $(libdir)/report'
echo '	chown $(AEGIS_UID) $(libdir)/report'
echo '	chgrp $(AEGIS_GID) $(libdir)/report'
echo '	chmod 0755 $(libdir)/report'
echo '	@touch .libdir.report'
echo "	@sleep 1"

echo ''
echo '#'
echo '# This target is used when preparing for the second'
echo '# pass of testing, when aegis is set-uid-root.'
echo '#'
echo 'install-libdir: .libdir'
echo '	chown root bin/aegis'
echo '	chmod 4755 bin/aegis'

echo ''
echo 'install-bin: $(bindir)/aegis'

echo ""
echo "install-man:" $man1_files $man5_files

echo ''
echo "install-lib:" $lib_files

echo ""
echo "install: install-bin install-man install-lib"

exit 0
